<?php

/**
 * Created by PhpStorm.
 * User: crose
 * Date: 12/23/15
 * Time: 7:11 PM
 */

namespace qfq;

use PHPUnit\Framework\TestCase;

/**
 * Class QuickFormQueryTest
 */
class QuickFormQueryTest extends TestCase {

    private $store;

//* FORM_LOAD:
//*   Specified in T3 body text with form=<formname>            Returned Store:Typo3
//*   Specified in T3 body text with form={{form}} ':FSRD'      Returned Store:SIP
//*   Specified in T3 body text with form={{form:C:ALNUMX}}     Returned Store:Client
//*   Specified in T3 body text with form={{SELECT registrationFormName FROM Conference WHERE id={{conferenceId:S0}} }}
//     *   Specified in T3 body text with form={{SELECT registrationFormName FROM Conference WHERE id={{conferenceId:C0:DIGIT}} }}
//     *   Specified in SIP
//*
//     * FORM_SAVE:
//     *   Specified in SIP
//*
//     *
//     * @param string $mode FORM_LOAD|FORM_SAVE|FORM_UPDATE
//* @param string $foundInStore
//* @return array|bool|mixed|null|string  Formname (Form.name) or FALSE, if no formname found.
//     * @throws CodeException
//* @throws UserFormException
//*/

    /**
     * @throws CodeException
     * @throws DbException
     * @throws UserFormException
     * @throws UserReportException
     */
    public function testGetFormName() {

        $store = Store::getInstance();

        // <empty> bodytext
        $store->unsetStore(STORE_TYPO3);
        $t3data[T3DATA_BODYTEXT] = "\n   \n \n";
        $t3data[T3DATA_UID] = "123";
        $qfq = new QuickFormQuery($t3data, true);
        $result = $qfq->getFormName(FORM_LOAD, $foundInStore);
        $this->assertEquals('', $result);

        // form=
        $store->unsetStore(STORE_TYPO3);
        $t3data[T3DATA_BODYTEXT] = "\n   \n" . TYPO3_FORM . "=\n";
        $t3data[T3DATA_UID] = "123";
        $qfq = new QuickFormQuery($t3data, true);
        $result = $qfq->getFormName(FORM_LOAD, $foundInStore);
        $this->assertEquals('', $result);

        // form=<formname>
        $store->unsetStore(STORE_TYPO3);
        $t3data[T3DATA_BODYTEXT] = "\n   \n" . TYPO3_FORM . "=myForm\n";
        $t3data[T3DATA_UID] = "123";
        $qfq = new QuickFormQuery($t3data, true);
        $result = $qfq->getFormName(FORM_LOAD, $foundInStore);
        $this->assertEquals('myForm', $result);

        // form={{SELECT 'nextForm'}}
        $store->unsetStore(STORE_TYPO3);
        $t3data[T3DATA_BODYTEXT] = "\n   \n" . TYPO3_FORM . "={{SELECT 'nextForm'}}\n";
        $t3data[T3DATA_UID] = "123";
        $qfq = new QuickFormQuery($t3data, true);
        $result = $qfq->getFormName(FORM_LOAD, $foundInStore);
        $this->assertEquals('nextForm', $result);

        // form={{form:C:alnumx}}
        $store->unsetStore(STORE_TYPO3);
        $store->setVar(CLIENT_FORM,'formNameViaGet' , STORE_CLIENT);
        $t3data[T3DATA_BODYTEXT] = "\n   \n" . TYPO3_FORM . "={{form:C:alnumx}}\n";
        $t3data[T3DATA_UID] = "123";
//        $_SERVER['form'] = 'formNameViaGet';
        $qfq = new QuickFormQuery($t3data, true);
        $result = $qfq->getFormName(FORM_LOAD, $foundInStore);
        $this->assertEquals('formNameViaGet', $result);

        // form={{form}}
//        $sip = new Sip('fakesessionname', true);
//        $sip->sipUniqId('badcaffee1234');
//        $t3data[T3DATA_BODYTEXT] = "\n   \n" . TYPO3_FORM . "={{form}}\n";
//        $t3data[T3DATA_UID] = "123";
//        $_SERVER[CLIENT_SIP]='badcaffee1234';
//        $dummy = $sip->queryStringToSip("http://example.com/index.php?id=input&r=1&form=person", RETURN_URL);
//        $qfq = new QuickFormQuery($t3data, true);
//        $result = $qfq->getFormName(FORM_LOAD, $foundInStore);
//        $this->assertEquals('person', $result);


    }

}
